@@ -1,16 +1,12 @@
-# Copyright 2014-2016 Ivan Kravets <me@ikravets.com>
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#    http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# -*- coding: utf-8 -*-
+# -- This file is part of the Apio project
+# -- (C) 2016 FPGAwars
+# -- Author Jesús Arroyo
+# -- Licence GPLv2
+# -- Derived from:
+# ---- Platformio project
+# ---- (C) 2014-2016 Ivan Kravets <me@ikravets.com>
+# ---- Licence Apache v2
 
 from os import chmod
 from os.path import join, splitext
@@ -20,8 +16,12 @@ from zipfile import ZipFile
 
 import click
 
-from . import util
-from .exception import UnsupportedArchiveType
+from apio import util
+
+
+class UnsupportedArchiveType(util.ApioException):
+
+    MESSAGE = "Can not unpack file '{0}'"
 
 
 class ArchiveBase(object):
@@ -29,10 +29,13 @@ class ArchiveBase(object):
     def __init__(self, arhfileobj):
         self._afo = arhfileobj
 
-    def get_items(self):
+    def get_items(self):  # pragma: no cover
         raise NotImplementedError()
 
     def extract_item(self, item, dest_dir):
+        if hasattr(item, 'filename') and \
+           item.filename.endswith('.gitignore'):
+            return
         self._afo.extract(item, dest_dir)
         self.after_extract(item, dest_dir)
 
@@ -64,7 +67,7 @@ class ZIPArchive(ArchiveBase):
     def preserve_mtime(item, dest_dir):
         util.change_filemtime(
             join(dest_dir, item.filename),
-            mktime(list(item.date_time) + [0] * 3)
+            mktime(tuple(list(item.date_time) + [0] * 3))
         )
 
     def get_items(self):
